@@ -851,13 +851,18 @@ static DumpFunc compat_funcs[] = {
 };
 
 static void set_state_depth(VALUE state, int depth) {
-    VALUE json_module = rb_const_get_at(rb_cObject, rb_intern("JSON"));
-    VALUE ext         = rb_const_get(json_module, rb_intern("Ext"));
-    VALUE generator   = rb_const_get(ext, rb_intern("Generator"));
-    VALUE state_class = rb_const_get(generator, rb_intern("State"));
+    if (0 == rb_const_defined(rb_cObject, rb_intern("JSON"))) {
+        rb_require("oj/json");
+    }
+    {
+        VALUE json_module = rb_const_get_at(rb_cObject, rb_intern("JSON"));
+        VALUE ext         = rb_const_get(json_module, rb_intern("Ext"));
+        VALUE generator   = rb_const_get(ext, rb_intern("Generator"));
+        VALUE state_class = rb_const_get(generator, rb_intern("State"));
 
-    if (state_class == rb_obj_class(state)) {
-        rb_funcall(state, rb_intern("depth="), 1, INT2NUM(depth));
+        if (state_class == rb_obj_class(state)) {
+            rb_funcall(state, rb_intern("depth="), 1, INT2NUM(depth));
+        }
     }
 }
 
@@ -865,20 +870,15 @@ void oj_dump_compat_val(VALUE obj, int depth, Out out, bool as_ok) {
     int type = rb_type(obj);
 
     TRACE(out->opts->trace, "dump", obj, depth, TraceIn);
+    // The max_nesting logic is that an empty Array or Hash is assumed to have
+    // content so the max_nesting should fail but a non-collection value is
+    // okay. That means a check for a collectable value is needed before
+    // raising.
     if (out->opts->dump_opts.max_depth <= depth) {
-        // When JSON.dump is called then an ArgumentError is expected and the
-        // limit is the depth inclusive. If JSON.generate is called then a
-        // NestingError is expected and the limit is inclusive. Worse than
-        // that there are unit tests for both.
-        if (CALLER_DUMP == out->caller) {
+        if (RUBY_T_ARRAY == type || RUBY_T_HASH == type) {
             if (0 < out->argc) {
                 set_state_depth(*out->argv, depth);
             }
-            rb_raise(rb_eArgError, "Too deeply nested.");
-        } else if (out->opts->dump_opts.max_depth < depth) {
-            if (0 < out->argc) {
-                set_state_depth(*out->argv, depth - 1);
-            }
             raise_json_err("Too deeply nested", "NestingError");
         }
     }
