@@ -20,7 +20,7 @@
 #define FRAC_LIMIT 10000000000000000ULL
 
 // Give better performance with indented JSON but worse with unindented.
-//#define SPACE_JUMP
+// #define SPACE_JUMP
 
 enum {
     SKIP_CHAR        = 'a',
@@ -1164,6 +1164,17 @@ static void parser_mark(void *ptr) {
     }
 }
 
+static const rb_data_type_t oj_parser_type = {
+    "Oj/parser",
+    {
+        parser_mark,
+        parser_free,
+        NULL,
+    },
+    0,
+    0,
+};
+
 extern void oj_set_parser_validator(ojParser p);
 extern void oj_set_parser_saj(ojParser p);
 extern void oj_set_parser_usual(ojParser p);
@@ -1180,7 +1191,7 @@ static int opt_cb(VALUE rkey, VALUE value, VALUE ptr) {
         rkey = rb_sym2str(rkey);
         // fall through
     case RUBY_T_STRING:
-        key  = rb_string_value_ptr(&rkey);
+        key  = StringValuePtr(rkey);
         klen = RSTRING_LEN(rkey);
         break;
     default: rb_raise(rb_eArgError, "option keys must be a symbol or string");
@@ -1255,7 +1266,7 @@ static VALUE parser_new(int argc, VALUE *argv, VALUE self) {
             rb_hash_foreach(ropts, opt_cb, (VALUE)p);
         }
     }
-    return Data_Wrap_Struct(parser_class, parser_mark, parser_free, p);
+    return TypedData_Wrap_Struct(parser_class, &oj_parser_type, p);
 }
 
 // Create a new parser without setting the delegate. The parser is
@@ -1275,7 +1286,7 @@ VALUE oj_parser_new(void) {
     buf_init(&p->buf);
     p->map = value_map;
 
-    return Data_Wrap_Struct(parser_class, parser_mark, parser_free, p);
+    return TypedData_Wrap_Struct(parser_class, &oj_parser_type, p);
 }
 
 // Set set the options from a hash (ropts).
@@ -1294,53 +1305,41 @@ void oj_parser_set_option(ojParser p, VALUE ropts) {
  *   - no options
  *
  * - *:saj*
- *   - _cache_keys=_ sets the value of the _cache_keys_ flag.
- *   - _cache_keys_ returns the value of the _cache_keys_ flag.
- *   - _cache_strings=_ sets the value of the _cache_strings_ to an positive integer less than 35. Strings shorter than
- * that length are cached.
- *   - _cache_strings_ returns the value of the _cache_strings_ integer value.
- *   - _handler=_ sets the SAJ handler
- *   - _handler_ returns the SAJ handler
+ *   - _cache_keys_ is a flag indicating hash keys should be cached.
+ *   - _cache_strings_ is a positive integer less than 35. Strings shorter than that length are cached.
+ *   - _handler_ is the SAJ handler
  *
  * - *:usual*
- *   - _cache_keys=_ sets the value of the _cache_keys_ flag.
- *   - _cache_keys_ returns the value of the _cache_keys_ flag.
- *   - _cache_strings=_ sets the value of the _cache_strings_ to a positive integer less than 35. Strings shorter than
- * that length are cached.
- *   - _cache_strings_ returns the value of the _cache_strings_ integer value.
- *   - _cache_expunge=_ sets the value of the _cache_expunge_ where 0 never expunges, 1 expunges slowly, 2 expunges
- * faster, and 3 or higher expunges agressively.
- *   - _cache_expunge_ returns the value of the _cache_expunge_ integer value.
- *   - _capacity=_ sets the capacity of the parser. The parser grows automatically but can be updated directly with this
- * call.
- *   - _capacity_ returns the current capacity of the parser's internal stack.
- *   - _create_id_ returns the value _create_id_ or _nil_ if there is no _create_id_.
- *   - _create_id=_ sets the value _create_id_ or if _nil_ unsets it. Parsed JSON objects that include the specified
- * element use the element value as the name of the class to create an object from instead of a Hash.
- *   - _decimal=_ sets the approach to how decimals are parser. If _:auto_ then the decimals with significant digits are
- * 16 or less are Floats and long ones are BigDecimal. _:ruby_ uses a call to Ruby to convert a string to a Float.
- * _:float_ always generates a Float. _:bigdecimal_ always results in a BigDecimal.
- *   - _decimal_ returns the value of the decimal conversion option which can be :auto (default), :ruby, :float, or
- * :bigdecimal.
- *   - _ignore_json_create_ returns the value of the _ignore_json_create_ flag.
- *   - _ignore_json_create=_ sets the value of the _ignore_json_create_ flag. When set the class json_create method is
- * ignored on parsing in favor of creating an instance and populating directly.
- *   - _missing_class_ return the value of the _missing_class_ indicator.
- *   - _missing_class=_ sets the value of the _missing_class_ flag. Valid values are _:auto_ which creates any missing
- * classes on parse, :ignore which ignores and continues as a Hash (default), and :raise which raises an exception if
- * the class is not found.
- *   - _omit_null=_ sets the _omit_null_ flag. If true then null values in a map or object are omitted from the
- * resulting Hash or Object.
- *   - _omit_null_ returns the value of the _omit_null_ flag.
- *   - _symbol_keys=_ sets the flag that indicates Hash keys should be parsed to Symbols versus Strings.
- *   - _symbol_keys_ returns the value of the _symbol_keys_ flag.
+ *   - _cache_keys_ is a flag indicating hash keys should be cached.
+ *   - _cache_strings_ is a positive integer less than 35. Strings shorter than that length are cached.
+ *   - _cache_expunge_ dictates when the cache will be expunged where 0 never expunges,
+ *     1 expunges slowly, 2 expunges faster, and 3 or higher expunges agressively.
+ *   - _capacity_ is the capacity of the parser's internal stack. The parser grows automatically
+ *     but can be updated directly with this call.
+ *   - _create_id_ if non-nil is the key that is used to specify the type of object to create
+ *     when parsing. Parsed JSON objects that include the specified element use the element
+ *     value as the name of the class to create an object from instead of a Hash.
+ *   - _decimal_ is the approach to how decimals are parsed. If _:auto_ then
+ *     the decimals with significant digits are 16 or less are Floats and long
+ *     ones are BigDecimal. _:ruby_ uses a call to Ruby to convert a string to a Float.
+ *     _:float_ always generates a Float. _:bigdecimal_ always results in a BigDecimal.
+ *   - _ignore_json_create_ is a flag that when set the class json_create method is
+ *     ignored on parsing in favor of creating an instance and populating directly.
+ *   - _missing_class_ is an indicator that determines how unknown class names are handled.
+ *     Valid values are _:auto_ which creates any missing classes on parse, :ignore which ignores
+ *     and continues as a Hash (default), and :raise which raises an exception if the class is not found.
+ *   - _omit_null_ is a flag that if true then null values in a map or object are omitted
+ *     from the resulting Hash or Object.
+ *   - _symbol_keys_ is a flag that indicates Hash keys should be parsed to Symbols versus Strings.
  */
 static VALUE parser_missing(int argc, VALUE *argv, VALUE self) {
-    ojParser       p    = (ojParser)DATA_PTR(self);
+    ojParser       p;
     const char    *key  = NULL;
     volatile VALUE rkey = *argv;
     volatile VALUE rv   = Qnil;
 
+    TypedData_Get_Struct(self, struct _ojParser, &oj_parser_type, p);
+
 #if HAVE_RB_EXT_RACTOR_SAFE
     // This doesn't seem to do anything.
     rb_ext_ractor_safe(true);
@@ -1349,7 +1348,7 @@ static VALUE parser_missing(int argc, VALUE *argv, VALUE self) {
     case RUBY_T_SYMBOL:
         rkey = rb_sym2str(rkey);
         // fall through
-    case RUBY_T_STRING: key = rb_string_value_ptr(&rkey); break;
+    case RUBY_T_STRING: key = StringValuePtr(rkey); break;
     default: rb_raise(rb_eArgError, "option method must be a symbol or string");
     }
     if (1 < argc) {
@@ -1366,12 +1365,14 @@ static VALUE parser_missing(int argc, VALUE *argv, VALUE self) {
  * Returns the result according to the delegate of the parser.
  */
 static VALUE parser_parse(VALUE self, VALUE json) {
-    ojParser p = (ojParser)DATA_PTR(self);
+    ojParser    p;
+    const byte *ptr = (const byte *)StringValuePtr(json);
+
+    TypedData_Get_Struct(self, struct _ojParser, &oj_parser_type, p);
 
-    Check_Type(json, T_STRING);
     parser_reset(p);
     p->start(p);
-    parse(p, (const byte *)rb_string_value_ptr(&json));
+    parse(p, ptr);
 
     return p->result(p);
 }
@@ -1382,9 +1383,11 @@ static VALUE load_rescue(VALUE self, VALUE x) {
 }
 
 static VALUE load(VALUE self) {
-    ojParser       p    = (ojParser)DATA_PTR(self);
+    ojParser       p;
     volatile VALUE rbuf = rb_str_new2("");
 
+    TypedData_Get_Struct(self, struct _ojParser, &oj_parser_type, p);
+
     p->start(p);
     while (true) {
         rb_funcall(p->reader, oj_readpartial_id, 2, INT2NUM(16385), rbuf);
@@ -1403,7 +1406,9 @@ static VALUE load(VALUE self) {
  * Returns the result according to the delegate of the parser.
  */
 static VALUE parser_load(VALUE self, VALUE reader) {
-    ojParser p = (ojParser)DATA_PTR(self);
+    ojParser p;
+
+    TypedData_Get_Struct(self, struct _ojParser, &oj_parser_type, p);
 
     parser_reset(p);
     p->reader = reader;
@@ -1420,12 +1425,13 @@ static VALUE parser_load(VALUE self, VALUE reader) {
  * Returns the result according to the delegate of the parser.
  */
 static VALUE parser_file(VALUE self, VALUE filename) {
-    ojParser    p = (ojParser)DATA_PTR(self);
+    ojParser    p;
     const char *path;
     int         fd;
 
-    Check_Type(filename, T_STRING);
-    path = rb_string_value_ptr(&filename);
+    TypedData_Get_Struct(self, struct _ojParser, &oj_parser_type, p);
+
+    path = StringValuePtr(filename);
 
     parser_reset(p);
     p->start(p);
@@ -1468,7 +1474,9 @@ static VALUE parser_file(VALUE self, VALUE filename) {
  * Returns the current state of the just_one [_Boolean_] option.
  */
 static VALUE parser_just_one(VALUE self) {
-    ojParser p = (ojParser)DATA_PTR(self);
+    ojParser p;
+
+    TypedData_Get_Struct(self, struct _ojParser, &oj_parser_type, p);
 
     return p->just_one ? Qtrue : Qfalse;
 }
@@ -1482,7 +1490,9 @@ static VALUE parser_just_one(VALUE self) {
  * Returns the current state of the just_one [_Boolean_] option.
  */
 static VALUE parser_just_one_set(VALUE self, VALUE v) {
-    ojParser p = (ojParser)DATA_PTR(self);
+    ojParser p;
+
+    TypedData_Get_Struct(self, struct _ojParser, &oj_parser_type, p);
 
     p->just_one = (Qtrue == v);
 
@@ -1506,7 +1516,7 @@ static VALUE parser_usual(VALUE self) {
         buf_init(&p->buf);
         p->map = value_map;
         oj_set_parser_usual(p);
-        usual_parser = Data_Wrap_Struct(parser_class, parser_mark, parser_free, p);
+        usual_parser = TypedData_Wrap_Struct(parser_class, &oj_parser_type, p);
         rb_gc_register_address(&usual_parser);
     }
     return usual_parser;
@@ -1529,7 +1539,7 @@ static VALUE parser_saj(VALUE self) {
         buf_init(&p->buf);
         p->map = value_map;
         oj_set_parser_saj(p);
-        saj_parser = Data_Wrap_Struct(parser_class, parser_mark, parser_free, p);
+        saj_parser = TypedData_Wrap_Struct(parser_class, &oj_parser_type, p);
         rb_gc_register_address(&saj_parser);
     }
     return saj_parser;
@@ -1551,7 +1561,7 @@ static VALUE parser_validate(VALUE self) {
         buf_init(&p->buf);
         p->map = value_map;
         oj_set_parser_validator(p);
-        validate_parser = Data_Wrap_Struct(parser_class, parser_mark, parser_free, p);
+        validate_parser = TypedData_Wrap_Struct(parser_class, &oj_parser_type, p);
         rb_gc_register_address(&validate_parser);
     }
     return validate_parser;
