@@ -3,9 +3,9 @@
 
 #include "rails.h"
 
-#include "mem.h"
 #include "code.h"
 #include "encode.h"
+#include "mem.h"
 #include "trace.h"
 #include "util.h"
 
@@ -16,7 +16,7 @@ typedef struct _encoder {
     struct _rOptTable ropts;
     struct _options   opts;
     VALUE             arg;
-} * Encoder;
+} *Encoder;
 
 bool oj_rails_hash_opt  = false;
 bool oj_rails_array_opt = false;
@@ -141,7 +141,7 @@ static void dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
     int            cnt;
     int            i;
     int            len;
-    const char *   name;
+    const char    *name;
 
 #ifdef RSTRUCT_LEN
 #if RSTRUCT_LEN_RETURNS_INTEGER_OBJECT
@@ -200,7 +200,7 @@ static void dump_enumerable(VALUE obj, int depth, Out out, bool as_ok) {
 
 static void dump_bigdecimal(VALUE obj, int depth, Out out, bool as_ok) {
     volatile VALUE rstr = oj_safe_string_convert(obj);
-    const char *   str  = RSTRING_PTR(rstr);
+    const char    *str  = RSTRING_PTR(rstr);
 
     if ('I' == *str || 'N' == *str || ('-' == *str && 'I' == str[1])) {
         oj_dump_nil(Qnil, depth, out, false);
@@ -263,14 +263,7 @@ static void dump_sec_nano(VALUE obj, int64_t sec, long nsec, Out out) {
                       tzmin);
     } else if (0 == out->opts->sec_prec) {
         if (0 == tzsecs && rb_funcall2(obj, oj_utcq_id, 0, 0)) {
-            len = sprintf(buf,
-                          "%04d-%02d-%02dT%02d:%02d:%02dZ",
-                          ti.year,
-                          ti.mon,
-                          ti.day,
-                          ti.hour,
-                          ti.min,
-                          ti.sec);
+            len = sprintf(buf, "%04d-%02d-%02dT%02d:%02d:%02dZ", ti.year, ti.mon, ti.day, ti.hour, ti.min, ti.sec);
         } else {
             len = sprintf(buf,
                           "%04d-%02d-%02dT%02d:%02d:%02d%c%02d:%02d",
@@ -301,18 +294,7 @@ static void dump_sec_nano(VALUE obj, int64_t sec, long nsec, Out out) {
             format[32] = '0' + out->opts->sec_prec;
             len -= 9 - out->opts->sec_prec;
         }
-        len = sprintf(buf,
-                      format,
-                      ti.year,
-                      ti.mon,
-                      ti.day,
-                      ti.hour,
-                      ti.min,
-                      ti.sec,
-                      nsec,
-                      tzsign,
-                      tzhour,
-                      tzmin);
+        len = sprintf(buf, format, ti.year, ti.mon, ti.day, ti.hour, ti.min, ti.sec, nsec, tzsign, tzhour, tzmin);
     }
     oj_dump_cstr(buf, len, 0, 0, out);
 }
@@ -356,7 +338,7 @@ static ID parameters_id = 0;
 typedef struct _strLen {
     const char *str;
     int         len;
-} * StrLen;
+} *StrLen;
 
 static void dump_actioncontroller_parameters(VALUE obj, int depth, Out out, bool as_ok) {
     if (0 == parameters_id) {
@@ -505,7 +487,7 @@ static void dump_activerecord_result(VALUE obj, int depth, Out out, bool as_ok)
 typedef struct _namedFunc {
     const char *name;
     DumpFunc    func;
-} * NamedFunc;
+} *NamedFunc;
 
 static void dump_as_string(VALUE obj, int depth, Out out, bool as_ok) {
     if (oj_code_dump(oj_compat_codes, obj, depth, out)) {
@@ -657,6 +639,17 @@ static void encoder_mark(void *ptr) {
     }
 }
 
+static const rb_data_type_t oj_encoder_type = {
+    "Oj/encoder",
+    {
+        encoder_mark,
+        encoder_free,
+        NULL,
+    },
+    0,
+    0,
+};
+
 /* Document-method: new
  *	call-seq: new(options=nil)
  *
@@ -674,14 +667,14 @@ static VALUE encoder_new(int argc, VALUE *argv, VALUE self) {
         oj_parse_options(*argv, &e->opts);
         e->arg = *argv;
     }
-    return Data_Wrap_Struct(encoder_class, encoder_mark, encoder_free, e);
+    return TypedData_Wrap_Struct(encoder_class, &oj_encoder_type, e);
 }
 
 static VALUE resolve_classpath(const char *name) {
     char        class_name[1024];
     VALUE       clas;
-    char *      end = class_name + sizeof(class_name) - 1;
-    char *      s;
+    char       *end = class_name + sizeof(class_name) - 1;
+    char       *s;
     const char *n = name;
     ID          cid;
 
@@ -747,8 +740,7 @@ static void optimize(int argc, VALUE *argv, ROptTable rot, bool on) {
             oj_rails_float_opt = on;
         } else if (oj_string_writer_class == *argv) {
             string_writer_optimized = on;
-        } else if (NULL != (ro = oj_rails_get_opt(rot, *argv)) ||
-                   NULL != (ro = create_opt(rot, *argv))) {
+        } else if (NULL != (ro = oj_rails_get_opt(rot, *argv)) || NULL != (ro = create_opt(rot, *argv))) {
             ro->on = on;
         }
     }
@@ -767,7 +759,8 @@ static void optimize(int argc, VALUE *argv, ROptTable rot, bool on) {
  * - *classes* [_Class_] a list of classes to optimize
  */
 static VALUE encoder_optimize(int argc, VALUE *argv, VALUE self) {
-    Encoder e = (Encoder)DATA_PTR(self);
+    Encoder e;
+    TypedData_Get_Struct(self, struct _encoder, &oj_encoder_type, e);
 
     optimize(argc, argv, &e->ropts, true);
 
@@ -810,7 +803,7 @@ rails_mimic_json(VALUE self) {
     }
     oj_mimic_json_methods(json);
     // Setting the default mode breaks the prmoise in the docs not to.
-    //oj_default_options.mode = RailsMode;
+    // oj_default_options.mode = RailsMode;
 
     return Qnil;
 }
@@ -823,7 +816,8 @@ rails_mimic_json(VALUE self) {
  * - *classes* [_Class_] a list of classes to deoptimize
  */
 static VALUE encoder_deoptimize(int argc, VALUE *argv, VALUE self) {
-    Encoder e = (Encoder)DATA_PTR(self);
+    Encoder e;
+    TypedData_Get_Struct(self, struct _encoder, &oj_encoder_type, e);
 
     optimize(argc, argv, &e->ropts, false);
 
@@ -852,8 +846,11 @@ static VALUE rails_deoptimize(int argc, VALUE *argv, VALUE self) {
  * @return true if the class is being optimized for rails and false otherwise
  */
 static VALUE encoder_optimized(VALUE self, VALUE clas) {
-    Encoder e  = (Encoder)DATA_PTR(self);
-    ROpt    ro = oj_rails_get_opt(&e->ropts, clas);
+    Encoder e;
+    ROpt    ro;
+
+    TypedData_Get_Struct(self, struct _encoder, &oj_encoder_type, e);
+    ro = oj_rails_get_opt(&e->ropts, clas);
 
     if (NULL == ro) {
         return Qfalse;
@@ -878,7 +875,7 @@ static VALUE rails_optimized(VALUE self, VALUE clas) {
 typedef struct _oo {
     Out   out;
     VALUE obj;
-} * OO;
+} *OO;
 
 static VALUE protect_dump(VALUE ov) {
     OO oo = (OO)ov;
@@ -908,16 +905,15 @@ static VALUE encode(VALUE obj, ROptTable ropts, Options opts, int argc, VALUE *a
 
     oj_out_init(&out);
 
-    out.omit_nil  = copts.dump_opts.omit_nil;
-    out.caller    = 0;
-    out.cur       = out.buf;
-    out.circ_cnt  = 0;
-    out.opts      = &copts;
-    out.hash_cnt  = 0;
-    out.indent    = copts.indent;
-    out.argc      = argc;
-    out.argv      = argv;
-    out.ropts     = ropts;
+    out.omit_nil = copts.dump_opts.omit_nil;
+    out.cur      = out.buf;
+    out.circ_cnt = 0;
+    out.opts     = &copts;
+    out.hash_cnt = 0;
+    out.indent   = copts.indent;
+    out.argc     = argc;
+    out.argv     = argv;
+    out.ropts    = ropts;
     if (Yes == copts.circular) {
         oj_cache8_new(&out.circ_cache);
     }
@@ -960,7 +956,8 @@ static VALUE encode(VALUE obj, ROptTable ropts, Options opts, int argc, VALUE *a
  * Returns encoded object as a JSON string.
  */
 static VALUE encoder_encode(VALUE self, VALUE obj) {
-    Encoder e = (Encoder)DATA_PTR(self);
+    Encoder e;
+    TypedData_Get_Struct(self, struct _encoder, &oj_encoder_type, e);
 
     if (Qnil != e->arg) {
         VALUE argv[1] = {e->arg};
@@ -1062,28 +1059,16 @@ static VALUE rails_set_encoder(VALUE self) {
     verbose = rb_gv_get("$VERBOSE");
     rb_gv_set("$VERBOSE", Qfalse);
     rb_undef_method(encoding, "use_standard_json_time_format=");
-    rb_define_module_function(encoding,
-                              "use_standard_json_time_format=",
-                              rails_use_standard_json_time_format,
-                              1);
+    rb_define_module_function(encoding, "use_standard_json_time_format=", rails_use_standard_json_time_format, 1);
     rb_undef_method(encoding, "use_standard_json_time_format");
-    rb_define_module_function(encoding,
-                              "use_standard_json_time_format",
-                              rails_use_standard_json_time_format_get,
-                              0);
+    rb_define_module_function(encoding, "use_standard_json_time_format", rails_use_standard_json_time_format_get, 0);
 
     pv          = rb_iv_get(encoding, "@escape_html_entities_in_json");
     escape_html = Qtrue == pv;
     rb_undef_method(encoding, "escape_html_entities_in_json=");
-    rb_define_module_function(encoding,
-                              "escape_html_entities_in_json=",
-                              rails_escape_html_entities_in_json,
-                              1);
+    rb_define_module_function(encoding, "escape_html_entities_in_json=", rails_escape_html_entities_in_json, 1);
     rb_undef_method(encoding, "escape_html_entities_in_json");
-    rb_define_module_function(encoding,
-                              "escape_html_entities_in_json",
-                              rails_escape_html_entities_in_json_get,
-                              0);
+    rb_define_module_function(encoding, "escape_html_entities_in_json", rails_escape_html_entities_in_json_get, 0);
 
     pv                              = rb_iv_get(encoding, "@time_precision");
     oj_default_options.sec_prec     = NUM2INT(pv);
@@ -1185,7 +1170,7 @@ static void dump_to_hash(VALUE obj, int depth, Out out) {
 
 static void dump_float(VALUE obj, int depth, Out out, bool as_ok) {
     char   buf[64];
-    char * b;
+    char  *b;
     double d   = rb_num2dbl(obj);
     int    cnt = 0;
 
