@@ -14,8 +14,8 @@
 // Workaround in case INFINITY is not defined in math.h or if the OS is CentOS
 #define OJ_INFINITY (1.0 / 0.0)
 
-#include "mem.h"
 #include "encode.h"
+#include "mem.h"
 #include "oj.h"
 
 typedef struct _parseInfo {
@@ -29,7 +29,7 @@ typedef struct _parseInfo {
     int   has_array_end;
     int   has_add_value;
     int   has_error;
-} * ParseInfo;
+} *ParseInfo;
 
 static void  read_next(ParseInfo pi, const char *key);
 static void  read_hash(ParseInfo pi, const char *key);
@@ -587,7 +587,7 @@ static void saj_parse(VALUE handler, char *json) {
         if (0 == getrlimit(RLIMIT_STACK, &lim) && RLIM_INFINITY != lim.rlim_cur) {
             pi.stack_min = (void *)((char *)&obj - (lim.rlim_cur / 4 * 3)); /* let 3/4ths of the stack be used only */
         } else {
-            pi.stack_min = 0; /* indicates not to check stack limit */
+            pi.stack_min = 0;                                               /* indicates not to check stack limit */
         }
     }
 #endif
@@ -642,7 +642,7 @@ oj_saj_parse(int argc, VALUE *argv, VALUE self) {
             s    = rb_funcall2(input, oj_string_id, 0, 0);
             len  = RSTRING_LEN(s) + 1;
             json = OJ_R_ALLOC_N(char, len);
-            strcpy(json, rb_string_value_cstr((VALUE *)&s));
+            strcpy(json, StringValueCStr(s));
 #if !IS_WINDOWS
         } else if (rb_cFile == clas && 0 == FIX2INT(rb_funcall(input, oj_pos_id, 0))) {
             int     fd = FIX2INT(rb_funcall(input, oj_fileno_id, 0));
@@ -660,7 +660,7 @@ oj_saj_parse(int argc, VALUE *argv, VALUE self) {
             s    = rb_funcall2(input, oj_read_id, 0, 0);
             len  = RSTRING_LEN(s) + 1;
             json = OJ_R_ALLOC_N(char, len);
-            strcpy(json, rb_string_value_cstr((VALUE *)&s));
+            strcpy(json, StringValueCStr(s));
         } else {
             rb_raise(rb_eArgError, "saj_parse() expected a String or IO Object.");
         }
