@@ -1,10 +1,11 @@
 // Copyright (c) 2021, Peter Ohler, All rights reserved.
 
-#include "mem.h"
+#include "usual.h"
+
 #include "cache.h"
+#include "mem.h"
 #include "oj.h"
 #include "parser.h"
-#include "usual.h"
 
 // The Usual delegate builds Ruby objects during parsing. It makes use of
 // three stacks. The first is the value stack. This is where parsed values are
@@ -90,8 +91,8 @@ static VALUE resolve_classname(VALUE mod, const char *classname, bool auto_defin
 static VALUE resolve_classpath(const char *name, size_t len, bool auto_define) {
     char        class_name[1024];
     VALUE       clas;
-    char *      end = class_name + sizeof(class_name) - 1;
-    char *      s;
+    char       *end = class_name + sizeof(class_name) - 1;
+    char       *s;
     const char *n = name;
 
     clas = rb_cObject;
@@ -186,7 +187,7 @@ static ID get_attr_id(ojParser p, Key kp) {
 }
 
 static void push_key(ojParser p) {
-    Usual    d    = (Usual)p->ctx;
+    Usual       d    = (Usual)p->ctx;
     size_t      klen = buf_len(&p->key);
     const char *key  = buf_str(&p->key);
 
@@ -270,14 +271,14 @@ static void open_array_key(ojParser p) {
 }
 
 static void close_object(ojParser p) {
-    VALUE *  vp;
-    Usual d = (Usual)p->ctx;
+    VALUE *vp;
+    Usual  d = (Usual)p->ctx;
 
     d->ctail--;
 
     Col            c    = d->ctail;
     Key            kp   = d->khead + c->ki;
-    VALUE *        head = d->vhead + c->vi + 1;
+    VALUE         *head = d->vhead + c->vi + 1;
     volatile VALUE obj  = rb_hash_new();
 
 #if HAVE_RB_HASH_BULK_INSERT
@@ -303,14 +304,14 @@ static void close_object(ojParser p) {
 }
 
 static void close_object_class(ojParser p) {
-    VALUE *  vp;
-    Usual d = (Usual)p->ctx;
+    VALUE *vp;
+    Usual  d = (Usual)p->ctx;
 
     d->ctail--;
 
     Col            c    = d->ctail;
     Key            kp   = d->khead + c->ki;
-    VALUE *        head = d->vhead + c->vi + 1;
+    VALUE         *head = d->vhead + c->vi + 1;
     volatile VALUE obj  = rb_class_new_instance(0, NULL, d->hash_class);
 
     for (vp = head; kp < d->ktail; kp++, vp += 2) {
@@ -326,14 +327,14 @@ static void close_object_class(ojParser p) {
 }
 
 static void close_object_create(ojParser p) {
-    VALUE *  vp;
-    Usual d = (Usual)p->ctx;
+    VALUE *vp;
+    Usual  d = (Usual)p->ctx;
 
     d->ctail--;
 
     Col            c    = d->ctail;
     Key            kp   = d->khead + c->ki;
-    VALUE *        head = d->vhead + c->vi;
+    VALUE         *head = d->vhead + c->vi;
     volatile VALUE obj;
 
     if (Qundef == *head) {
@@ -409,7 +410,7 @@ static void close_array(ojParser p) {
     Usual d = (Usual)p->ctx;
 
     d->ctail--;
-    VALUE *        head = d->vhead + d->ctail->vi + 1;
+    VALUE         *head = d->vhead + d->ctail->vi + 1;
     volatile VALUE a    = rb_ary_new_from_values(d->vtail - head, head);
 
     d->vtail = head;
@@ -418,11 +419,11 @@ static void close_array(ojParser p) {
 }
 
 static void close_array_class(ojParser p) {
-    VALUE *  vp;
-    Usual d = (Usual)p->ctx;
+    VALUE *vp;
+    Usual  d = (Usual)p->ctx;
 
     d->ctail--;
-    VALUE *        head = d->vhead + d->ctail->vi + 1;
+    VALUE         *head = d->vhead + d->ctail->vi + 1;
     volatile VALUE a    = rb_class_new_instance(0, NULL, d->array_class);
 
     for (vp = head; vp < d->vtail; vp++) {
@@ -532,9 +533,9 @@ static void add_big_as_ruby_key(ojParser p) {
 }
 
 static void add_str(ojParser p) {
-    Usual       d = (Usual)p->ctx;
+    Usual          d = (Usual)p->ctx;
     volatile VALUE rstr;
-    const char *   str = buf_str(&p->buf);
+    const char    *str = buf_str(&p->buf);
     size_t         len = buf_len(&p->buf);
 
     if (len < d->cache_str) {
@@ -546,9 +547,9 @@ static void add_str(ojParser p) {
 }
 
 static void add_str_key(ojParser p) {
-    Usual       d = (Usual)p->ctx;
+    Usual          d = (Usual)p->ctx;
     volatile VALUE rstr;
-    const char *   str = buf_str(&p->buf);
+    const char    *str = buf_str(&p->buf);
     size_t         len = buf_len(&p->buf);
 
     if (len < d->cache_str) {
@@ -561,11 +562,11 @@ static void add_str_key(ojParser p) {
 }
 
 static void add_str_key_create(ojParser p) {
-    Usual       d = (Usual)p->ctx;
+    Usual          d = (Usual)p->ctx;
     volatile VALUE rstr;
-    const char *   str  = buf_str(&p->buf);
+    const char    *str  = buf_str(&p->buf);
     size_t         len  = buf_len(&p->buf);
-    const char *   key  = buf_str(&p->key);
+    const char    *key  = buf_str(&p->key);
     size_t         klen = buf_len(&p->key);
 
     if (klen == (size_t)d->create_id_len && 0 == strncmp(d->create_id, key, klen)) {
@@ -600,6 +601,9 @@ static VALUE result(ojParser p) {
     if (d->vhead < d->vtail) {
         return *d->vhead;
     }
+    if (d->raise_on_empty) {
+        rb_raise(oj_parse_error_class, "empty string");
+    }
     return Qnil;
 }
 
@@ -634,8 +638,8 @@ static void mark(ojParser p) {
     if (NULL == p || NULL == p->ctx) {
         return;
     }
-    Usual d = (Usual)p->ctx;
-    VALUE *  vp;
+    Usual  d = (Usual)p->ctx;
+    VALUE *vp;
 
     if (NULL == d) {
         return;
@@ -729,7 +733,7 @@ static VALUE opt_cache_strings(ojParser p, VALUE value) {
 
 static VALUE opt_cache_strings_set(ojParser p, VALUE value) {
     Usual d     = (Usual)p->ctx;
-    int      limit = NUM2INT(value);
+    int   limit = NUM2INT(value);
 
     if (CACHE_MAX_KEY < limit) {
         limit = CACHE_MAX_KEY;
@@ -749,7 +753,7 @@ static VALUE opt_cache_expunge(ojParser p, VALUE value) {
 
 static VALUE opt_cache_expunge_set(ojParser p, VALUE value) {
     Usual d    = (Usual)p->ctx;
-    int      rate = NUM2INT(value);
+    int   rate = NUM2INT(value);
 
     if (rate < 0) {
         rate = 0;
@@ -773,7 +777,7 @@ static VALUE opt_capacity(ojParser p, VALUE value) {
 
 static VALUE opt_capacity_set(ojParser p, VALUE value) {
     Usual d   = (Usual)p->ctx;
-    long     cap = NUM2LONG(value);
+    long  cap = NUM2LONG(value);
 
     if (d->vend - d->vhead < cap) {
         long pos = d->vtail - d->vhead;
@@ -871,7 +875,7 @@ static VALUE opt_decimal(ojParser p, VALUE value) {
 }
 
 static VALUE opt_decimal_set(ojParser p, VALUE value) {
-    const char *   mode;
+    const char    *mode;
     volatile VALUE s;
 
     switch (rb_type(value)) {
@@ -987,8 +991,8 @@ static VALUE opt_missing_class(ojParser p, VALUE value) {
 }
 
 static VALUE opt_missing_class_set(ojParser p, VALUE value) {
-    Usual       d = (Usual)p->ctx;
-    const char *   mode;
+    Usual          d = (Usual)p->ctx;
+    const char    *mode;
     volatile VALUE s;
 
     switch (rb_type(value)) {
@@ -1065,36 +1069,52 @@ static VALUE opt_symbol_keys_set(ojParser p, VALUE value) {
     return (NULL != d->sym_cache) ? Qtrue : Qfalse;
 }
 
+static VALUE opt_raise_on_empty(ojParser p, VALUE value) {
+    Usual d = (Usual)p->ctx;
+
+    return d->raise_on_empty ? Qtrue : Qfalse;
+}
+
+static VALUE opt_raise_on_empty_set(ojParser p, VALUE value) {
+    Usual d = (Usual)p->ctx;
+
+    d->raise_on_empty = (Qtrue == value);
+
+    return d->raise_on_empty ? Qtrue : Qfalse;
+}
+
 static VALUE option(ojParser p, const char *key, VALUE value) {
     struct opt *op;
     struct opt  opts[] = {
-         {.name = "array_class", .func = opt_array_class},
-         {.name = "array_class=", .func = opt_array_class_set},
-         {.name = "cache_keys", .func = opt_cache_keys},
-         {.name = "cache_keys=", .func = opt_cache_keys_set},
-         {.name = "cache_strings", .func = opt_cache_strings},
-         {.name = "cache_strings=", .func = opt_cache_strings_set},
-         {.name = "cache_expunge", .func = opt_cache_expunge},
-         {.name = "cache_expunge=", .func = opt_cache_expunge_set},
-         {.name = "capacity", .func = opt_capacity},
-         {.name = "capacity=", .func = opt_capacity_set},
-         {.name = "class_cache", .func = opt_class_cache},
-         {.name = "class_cache=", .func = opt_class_cache_set},
-         {.name = "create_id", .func = opt_create_id},
-         {.name = "create_id=", .func = opt_create_id_set},
-         {.name = "decimal", .func = opt_decimal},
-         {.name = "decimal=", .func = opt_decimal_set},
-         {.name = "hash_class", .func = opt_hash_class},
-         {.name = "hash_class=", .func = opt_hash_class_set},
-         {.name = "ignore_json_create", .func = opt_ignore_json_create},
-         {.name = "ignore_json_create=", .func = opt_ignore_json_create_set},
-         {.name = "missing_class", .func = opt_missing_class},
-         {.name = "missing_class=", .func = opt_missing_class_set},
-         {.name = "omit_null", .func = opt_omit_null},
-         {.name = "omit_null=", .func = opt_omit_null_set},
-         {.name = "symbol_keys", .func = opt_symbol_keys},
-         {.name = "symbol_keys=", .func = opt_symbol_keys_set},
-         {.name = NULL},
+        {.name = "array_class", .func = opt_array_class},
+        {.name = "array_class=", .func = opt_array_class_set},
+        {.name = "cache_keys", .func = opt_cache_keys},
+        {.name = "cache_keys=", .func = opt_cache_keys_set},
+        {.name = "cache_strings", .func = opt_cache_strings},
+        {.name = "cache_strings=", .func = opt_cache_strings_set},
+        {.name = "cache_expunge", .func = opt_cache_expunge},
+        {.name = "cache_expunge=", .func = opt_cache_expunge_set},
+        {.name = "capacity", .func = opt_capacity},
+        {.name = "capacity=", .func = opt_capacity_set},
+        {.name = "class_cache", .func = opt_class_cache},
+        {.name = "class_cache=", .func = opt_class_cache_set},
+        {.name = "create_id", .func = opt_create_id},
+        {.name = "create_id=", .func = opt_create_id_set},
+        {.name = "decimal", .func = opt_decimal},
+        {.name = "decimal=", .func = opt_decimal_set},
+        {.name = "hash_class", .func = opt_hash_class},
+        {.name = "hash_class=", .func = opt_hash_class_set},
+        {.name = "ignore_json_create", .func = opt_ignore_json_create},
+        {.name = "ignore_json_create=", .func = opt_ignore_json_create_set},
+        {.name = "missing_class", .func = opt_missing_class},
+        {.name = "missing_class=", .func = opt_missing_class_set},
+        {.name = "omit_null", .func = opt_omit_null},
+        {.name = "omit_null=", .func = opt_omit_null_set},
+        {.name = "symbol_keys", .func = opt_symbol_keys},
+        {.name = "symbol_keys=", .func = opt_symbol_keys_set},
+        {.name = "raise_on_empty", .func = opt_raise_on_empty},
+        {.name = "raise_on_empty=", .func = opt_raise_on_empty_set},
+        {.name = NULL},
     };
 
     for (op = opts; NULL != op->name; op++) {
@@ -1110,7 +1130,7 @@ static VALUE option(ojParser p, const char *key, VALUE value) {
 ///// the set up //////////////////////////////////////////////////////////////
 
 void oj_init_usual(ojParser p, Usual d) {
-    int      cap = 4096;
+    int cap = 4096;
 
     d->vhead = OJ_R_ALLOC_N(VALUE, cap);
     d->vend  = d->vhead + cap;
@@ -1128,6 +1148,7 @@ void oj_init_usual(ojParser p, Usual d) {
     d->get_key            = cache_key;
     d->cache_keys         = true;
     d->ignore_json_create = false;
+    d->raise_on_empty     = false;
     d->cache_str          = 6;
     d->array_class        = Qnil;
     d->hash_class         = Qnil;
