@@ -3,7 +3,7 @@
 
 $LOAD_PATH << __dir__
 @oj_dir = File.dirname(File.expand_path(__dir__))
-%w(lib ext).each do |dir|
+%w[lib ext].each do |dir|
   $LOAD_PATH << File.join(@oj_dir, dir)
 end
 
